aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTimothy Stranex <timothy@Timothys-MacBook-Pro.local>2013-09-02 17:27:27 +0200
committerWladimir J. van der Laan <laanwj@gmail.com>2013-12-05 09:15:41 +0100
commit3b8868dca49ba4e317d562279d2128ed8fff9a81 (patch)
treef933b309ad647acee91145f9aa56ac63f93e36d1
parentdf0f6d020a97181d97b5f232e1310b1e982edf36 (diff)
downloadbitcoin-3b8868dca49ba4e317d562279d2128ed8fff9a81.tar.xz
Fix typo in a comment: it's base58, not base48.
-rw-r--r--src/qt/bitcoinaddressvalidator.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/qt/bitcoinaddressvalidator.h b/src/qt/bitcoinaddressvalidator.h
index 2b6a59367d..b7f4dfee96 100644
--- a/src/qt/bitcoinaddressvalidator.h
+++ b/src/qt/bitcoinaddressvalidator.h
@@ -3,8 +3,8 @@
#include <QValidator>
-/** Base48 entry widget validator.
- Corrects near-miss characters and refuses characters that are no part of base48.
+/** Base58 entry widget validator.
+ Corrects near-miss characters and refuses characters that are not part of base58.
*/
class BitcoinAddressValidator : public QValidator
{